# ![Voltaire](https://raw.githubusercontent.com/avengerpenguin/voltaire/main/logo.png)

[![Build Status](https://travis-ci.com/avengerpenguin/voltaire.svg?branch=main)](https://travis-ci.com/avengerpenguin/voltaire)

Tools for prolific writers (or more accurately, those that want to be).
